#!/bin/sh

# This script reads serial data from /dev/ttyUSB0
# and log readings every 30 seconds to the file 'data'
# It also outputs configuration data for GNUPlot.
# You can also watch in realtime your Batt's become flats.
# by piping this script into gnuplot with:
# ./record_data_from_ttyUSB0.sh | gnuplot 

stty -F /dev/ttyUSB0 57600 -raw -hup # Set baud rate to match Arduino. 
echo -n "" > data # create a file to store time, cell and voltages.
sleep 1 # 1 second delay for initialisation of RS232 and log file.

  echo set xdata time # all the echo's set config for GNUPlot.
  echo set timefmt \"%H:%M:%S\"
  echo set format x \"%H:%M:%S\"
  echo set datafile separator \",\"
  echo set title \"Battery discharge curves\"
  echo set yrange [0:2]
  echo set mytics
  echo set grid xtics ytics mytics
  echo set xlabel \"Time \(Hours:Minutes\)\"
  echo set ylabel \"Volts\"

while true; do # Loop while reading/writing/plotting data.
  cat /dev/ttyUSB0 | sed q >> data # read /dev/ttyUSB0 and add to data log.
  echo plot \"data\" using 1:3 title \"Cell 1\" smooth bezier, \"data\" using 1:5 title \"Cell 2\" smooth bezier, \"data\" using 1:7 title \"Cell 3\" smooth bezier, \"data\" using 1:9 title \"Cell 4\" smooth bezier
done 

